### Name: dcemri.bayes
### Title: Bayesian Methods for Pharmacokinetic Modeling of Dynamic
###   Contrast-Enhanced MRI Data
### Aliases: dcemri.bayes dcemri.bayes.single
### Keywords: models

### ** Examples

data("buckley")
xi <- seq(5, 300, by=5)
img <- array(t(breast$data)[,xi], c(13,1,1,60))
mask <- array(TRUE, dim(img)[1:3])
time <- buckley$time.min[xi]

## Bayesian estimation with Fritz-Hansen default AIF
fit.bayes <- dcemri.bayes(img, time, mask, aif="fritz.hansen", nriters=1500)

## Bayesian estimation with "orton.exp" function fit to Buckley's AIF
aif <- buckley$input[xi]
aifparams <- orton.exp.lm(time, aif)
aifparams$D <- 1
fit.bayes.aif <- dcemri.bayes(img, time, mask, model="orton.exp",
                              aif="user", user=aifparams, nriters=1500)

plot(breast$ktrans, fit.bayes$ktrans, xlim=c(0,1), ylim=c(0,1),
     xlab=expression(paste("True ", K^{trans})),
     ylab=expression(paste("Estimated ", K^{trans}, " (Bayesian)")))
points(breast$ktrans, fit.bayes.aif$ktrans, pch=2)
abline(0, 1, lwd=1.5, col=2)
legend("right", c("orton.exp", "fritz.hansen"), pch=1:2)

cbind(breast$ktrans, fit.bayes$ktrans[,,1], fit.bayes.aif$ktrans[,,1])

## Not run: 
##D fit.lm <- dcemri.lm(img, time, mask, aif="fritz.hansen")
##D fit.lm.aif <- dcemri.lm(img, time, mask, model="orton.exp", aif="user",
##D                         user=aifparams)
##D 
##D plot(breast$ktrans, fit.bayes$ktrans, xlim=c(0,1), ylim=c(0,1),
##D      xlab=expression(paste("True ", K^{trans})),
##D      ylab=expression(paste("Estimated ", K^{trans})))
##D points(breast$ktrans, fit.bayes.aif$ktrans, pch=2)
##D points(breast$ktrans, fit.lm$ktrans, pch=3)
##D points(breast$ktrans, fit.lm.aif$ktrans, pch=4)
##D abline(0, 1, lwd=1.5, col="red")
##D legend("bottomright", c("Bayesian Estimation (fritz-hansen)",
##D                         "Bayesian Estimation (orton.exp)",
##D                         "Levenburg-Marquardt (fritz.hansen)",
##D                         "Levenburg-Marquardt (orton.exp)"), pch=1:4)
## End(Not run)



