### Name: dcemri.map
### Title: Pharmacokinetic Modeling of Dynamic Contrast-Enhanced MRI Data
### Aliases: dcemri.map dcemri.map.single
### Keywords: models

### ** Examples

data("buckley")
xi <- seq(5, 300, by=5)
img <- array(t(breast$data)[,xi], c(13,1,1,60))
mask <- array(TRUE, dim(img)[1:3])
time <- buckley$time.min[xi]

## MAP estimation with Fritz-Hansen default AIF
fit.map <- dcemri.map(img, time, mask, aif="fritz.hansen",
                      nriters=5000)

plot(breast$ktrans, fit.map$ktrans, xlim=c(0,1), ylim=c(0,1),
     xlab=expression(paste("True ", K^{trans})),
     ylab=expression(paste("Estimated ", K^{trans}, " (MAP)")))
abline(0, 1, lwd=1.5, col=2)

## Not run: 
##D fit.lm <- dcemri.lm(img, time, mask, aif="fritz.hansen")
##D 
##D plot(breast$ktrans, fit.map$ktrans, xlim=c(0,1), ylim=c(0,1),
##D      xlab=expression(paste("True ", K^{trans})),
##D      ylab=expression(paste("Estimated ", K^{trans})))
##D points(breast$ktrans, fit.lm$ktrans, pch=3)
##D abline(0, 1, lwd=1.5, col="red")
##D legend("bottomright", c("MAP Estimation (fritz-hansen)",
##D                         "Levenburg-Marquardt (fritz.hansen)", pch=c(1,3))
## End(Not run)



