### Name: dcemri.lm
### Title: Pharmacokinetic Models for Dynamic Contrast-Enhanced MRI Data
### Aliases: dcemri.lm
### Keywords: models

### ** Examples

data("buckley")

## Set up breast data for dcemri
xi <- seq(5, 300, by=5)
img <- array(t(breast$data)[,xi], c(13,1,1,60))
time <- buckley$time.min[xi]
aif <- buckley$input[xi]
mask <- array(TRUE, dim(img)[1:3])

## Generate AIF params using the orton.exp function from Buckley's AIF
aifparams <- orton.exp.lm(time, aif)
fit <- dcemri.lm(img, time, mask, model="orton.exp",
                 aif="user", user=aifparams)

## Scatterplot comparing true and estimated Ktrans values
plot(breast$ktrans, fit$ktrans, xlim=c(0,0.75), ylim=c(0,0.75),
     xlab=expression(paste("True ", K^{trans})),
     ylab=expression(paste("Estimated ", K^{trans})))
abline(0, 1, lwd=1.5, col="red")
cbind(breast$ktrans, fit$ktrans[,,1])



