### Name: Write Output as Analyze/NIfTI
### Title: Write Analyze/NIfTI Format Binary Image Files
### Aliases: write.analyze.img write.nifti.img
### Keywords: file

### ** Examples

norm <- dnorm(seq(-5, 5, length=32), sd=2)
norm <- (norm-min(norm)) / max(norm-min(norm))
img <- outer(outer(norm, norm), norm)
img <- round(255*img)
img[17:32,,] <- 255 - img[17:32,,]
X <- nrow(img)
Y <- ncol(img)
Z <- nsli(img)

## NIfTI
nhdr <- make.hdr(X, Y, Z, 1, "INT", "nifti")
## Not run: 
##D write.nifti.img("test-image-int16", nhdr, img, "int16")
##D ## These files should be viewable in, for example, FSLview
##D ## Make sure you adjust the min/max values for proper visualization
##D data <- read.img("test-image-int16.nii.gz")
##D par(mfrow=c(6,6), mar=rep(0,4))
##D for (z in 1:32)
##D   image(img[,,z], zlim=range(img), col=grey(0:255/255), xlab="",
##D         ylab="", axes=FALSE)
##D for (z in 1:32)
##D   image(data[,,z,1], zlim=range(img), col=grey(0:255/255), xlab="",
##D         ylab="", axes=FALSE)
##D for (z in 1:32)
##D   image(abs(data[,,z,1] - img[,,z]), zlim=range(img),
##D         col=grey(0:255/255), xlab="", ylab="", axes=FALSE)
## End(Not run)

## Loop through all possible data types
datatypes <- c("uint8", "int16", "int32", "float", "double")
equal <- vector("list")
for (x in 1:length(datatypes)) {
  fname <- paste("test-image-", datatypes[x], sep="")
  write.nifti.img(fname, nhdr, img, datatypes[x])
  equal[[x]] <- all(drop(read.img(fname)) == img)
}
names(equal) <- datatypes
unlist(equal)

## Analyze (datatypes are the same as NIfTI)
hdr <- make.hdr(X, Y, Z, 1, "int16")
equal <- vector("list")
for (x in 1:length(datatypes)) {
  fname <- paste("test-analyze-image-", datatypes[x], sep="")
  write.analyze.img(fname, hdr, img, datatypes[x])
  equal[[x]] <- all(drop(read.img(fname)) == img)
}
names(equal) <- datatypes
unlist(equal)



